@@ -1,7 +1,12 @@
-package SVN::Hooks::AllowLogChange;
-
 use strict;
 use warnings;
+
+package SVN::Hooks::AllowLogChange;
+{
+  $SVN::Hooks::AllowLogChange::VERSION = '1.13';
+}
+# ABSTRACT: Allow changes in revision log messages.
+
 use Carp;
 use SVN::Hooks;
 
@@ -9,51 +14,6 @@ use Exporter qw/import/;
 my $HOOK = 'ALLOW_LOG_CHANGE';
 our @EXPORT = ($HOOK);
 
-our $VERSION = $SVN::Hooks::VERSION;
-
-=head1 NAME
-
-SVN::Hooks::AllowLogChange - Allow changes in revision log messages.
-
-=head1 SYNOPSIS
-
-This SVN::Hooks plugin is used to allow revision log changes by some
-users.
-
-It's deprecated. You should use SVN::Hooks::AllowPropChange instead.
-
-It's active in the C<pre-revprop-change> hook.
-
-It's configured by the following directive.
-
-=head2 ALLOW_LOG_CHANGE(WHO, ...)
-
-This directive enables the change of revision log messages, which are
-mantained in the C<svn:log> revision property.
-
-The optional WHO argument specifies the users that are allowed to make
-those changes. If absent, any user can change a log
-message. Otherwise, it specifies the allowed users depending on its
-type.
-
-=over
-
-=item STRING
-
-Specify a single user by name.
-
-=item REGEXP
-
-Specify the class of users whose names are matched by the
-Regexp.
-
-=back
-
-	ALLOW_LOG_CHANGE();
-	ALLOW_LOG_CHANGE('jsilva');
-	ALLOW_LOG_CHANGE(qr/silva$/);
-
-=cut
 
 my @Valid_Users;
 
@@ -93,54 +53,69 @@ sub pre_revprop_change {
     croak "$HOOK: you are not allowed to change a revision log.\n";
 }
 
-=head1 AUTHOR
+1; # End of SVN::Hooks::AllowLogChange
 
-Gustavo Chaves, C<< <gnustavo@cpan.org> >>
+__END__
+=pod
 
-=head1 BUGS
+=head1 NAME
 
-Please report any bugs or feature requests to
-C<bug-svn-hooks-checkproperty at rt.cpan.org>, or through the web
-interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=SVN-Hooks>.  I will
-be notified, and then you'll automatically be notified of progress on
-your bug as I make changes.
+SVN::Hooks::AllowLogChange - Allow changes in revision log messages.
 
-=head1 SUPPORT
+=head1 VERSION
 
-You can find documentation for this module with the perldoc command.
+version 1.13
 
-    perldoc SVN::Hooks
+=head1 SYNOPSIS
 
-You can also look for information at:
+This SVN::Hooks plugin is used to allow revision log changes by some
+users.
 
-=over 4
+It's deprecated. You should use SVN::Hooks::AllowPropChange instead.
 
-=item * RT: CPAN's request tracker
+It's active in the C<pre-revprop-change> hook.
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=SVN-Hooks>
+It's configured by the following directive.
 
-=item * AnnoCPAN: Annotated CPAN documentation
+=head2 ALLOW_LOG_CHANGE(WHO, ...)
 
-L<http://annocpan.org/dist/SVN-Hooks>
+This directive enables the change of revision log messages, which are
+mantained in the C<svn:log> revision property.
 
-=item * CPAN Ratings
+The optional WHO argument specifies the users that are allowed to make
+those changes. If absent, any user can change a log
+message. Otherwise, it specifies the allowed users depending on its
+type.
 
-L<http://cpanratings.perl.org/d/SVN-Hooks>
+=over
 
-=item * Search CPAN
+=item STRING
 
-L<http://search.cpan.org/dist/SVN-Hooks>
+Specify a single user by name.
+
+=item REGEXP
+
+Specify the class of users whose names are matched by the
+Regexp.
 
 =back
 
-=head1 COPYRIGHT & LICENSE
+	ALLOW_LOG_CHANGE();
+	ALLOW_LOG_CHANGE('jsilva');
+	ALLOW_LOG_CHANGE(qr/silva$/);
 
-Copyright 2008-2011 CPqD, all rights reserved.
+=for Pod::Coverage pre_revprop_change
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+=head1 AUTHOR
+
+Gustavo L. de M. Chaves <gnustavo@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by CPqD.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1; # End of SVN::Hooks::AllowLogChange
