@@ -1,7 +1,12 @@
-package SVN::Hooks::AllowPropChange;
-
 use strict;
 use warnings;
+
+package SVN::Hooks::AllowPropChange;
+{
+  $SVN::Hooks::AllowPropChange::VERSION = '1.13';
+}
+# ABSTRACT: Allow changes in revision properties.
+
 use Carp;
 use SVN::Hooks;
 
@@ -9,12 +14,77 @@ use Exporter qw/import/;
 my $HOOK = 'ALLOW_PROP_CHANGE';
 our @EXPORT = ($HOOK);
 
-our $VERSION = $SVN::Hooks::VERSION;
+
+my @Specs;
+
+sub ALLOW_PROP_CHANGE {
+    my @args = @_;
+
+    my @whos;
+
+    foreach my $arg (@args) {
+	if (not ref $arg or ref $arg eq 'Regexp') {
+	    push @whos, $arg;
+	}
+	else {
+	    croak "$HOOK: invalid argument '$arg'\n";
+	}
+    }
+
+    @whos != 0
+	or croak "$HOOK: you must specify at least the first argument\n";
+
+    my $prop = shift @whos;
+    push @Specs, [$prop => \@whos];
+
+    PRE_REVPROP_CHANGE(\&pre_revprop_change);
+
+    return 1;
+}
+
+sub pre_revprop_change {
+    my ($svnlook, $rev, $author, $propname, $action) = @_;
+
+    $propname =~ /^svn:(?:author|date|log)$/
+	or croak "$HOOK: the revision property $propname cannot be changed.\n";
+
+    $action eq 'M'
+	or croak "$HOOK: revision properties can only be modified, not added or deleted.\n";
+
+    foreach my $spec (@Specs) {
+	my ($prop, $whos) = @$spec;
+	if (! ref $prop) {
+	    next if $propname ne $prop;
+	}
+	else {
+	    next if $propname !~ $prop;
+	}
+	for my $who (@$whos) {
+	    if (! ref $who) {
+		return if $author eq $who;
+	    }
+	    else {
+		return if $author =~ $who;
+	    }
+	}
+    }
+
+    croak "$HOOK: you are not allowed to change property $propname.\n";
+}
+
+1; # End of SVN::Hooks::AllowPropChange
+
+__END__
+=pod
 
 =head1 NAME
 
 SVN::Hooks::AllowPropChange - Allow changes in revision properties.
 
+=head1 VERSION
+
+version 1.13
+
 =head1 SYNOPSIS
 
 This SVN::Hooks plugin is used to allow revision (or non-versioned)
@@ -67,116 +137,18 @@ Specify the class of users whose names are matched by the Regexp.
 	ALLOW_PROP_CHANGE('svn:log' => 'jsilva'); # jsilva can change svn:log
 	ALLOW_PROP_CHANGE(qr/./ => qr/silva$/); # any *silva can change any property
 
-=cut
-
-sub ALLOW_PROP_CHANGE {
-    my @args = @_;
-
-    my $conf = $SVN::Hooks::Confs->{$HOOK};
-
-    my @whos;
-
-    foreach my $arg (@args) {
-	if (not ref $arg or ref $arg eq 'Regexp') {
-	    push @whos, $arg;
-	}
-	else {
-	    croak "$HOOK: invalid argument '$arg'\n";
-	}
-    }
-
-    @whos != 0
-	or croak "$HOOK: you must specify at least the first argument\n";
-
-    my $prop = shift @whos;
-    push @{$conf->{specs}}, [$prop => \@whos];
-    $conf->{'pre-revprop-change'} = \&pre_revprop_change;
-
-    return 1;
-}
-
-$SVN::Hooks::Inits{$HOOK} = sub {
-    return { specs => [] };
-};
-
-sub pre_revprop_change {
-    my ($self, $svnlook, $rev, $author, $propname, $action) = @_;
-
-    $propname =~ /^svn:(?:author|date|log)$/
-	or croak "$HOOK: the revision property $propname cannot be changed.\n";
-
-    $action eq 'M'
-	or croak "$HOOK: revision properties can only be modified, not added or deleted.\n";
-
-    foreach my $spec (@{$self->{specs}}) {
-	my ($prop, $whos) = @$spec;
-	if (! ref $prop) {
-	    next if $propname ne $prop;
-	}
-	else {
-	    next if $propname !~ $prop;
-	}
-	for my $who (@$whos) {
-	    if (! ref $who) {
-		return if $author eq $who;
-	    }
-	    else {
-		return if $author =~ $who;
-	    }
-	}
-    }
-
-    croak "$HOOK: you are not allowed to change property $propname.\n";
-}
+=for Pod::Coverage pre_revprop_change
 
 =head1 AUTHOR
 
-Gustavo Chaves, C<< <gnustavo@cpan.org> >>
+Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-Please report any bugs or feature requests to
-C<bug-svn-hooks-checkproperty at rt.cpan.org>, or through the web
-interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=SVN-Hooks>.  I will
-be notified, and then you'll automatically be notified of progress on
-your bug as I make changes.
+This software is copyright (c) 2012 by CPqD.
 
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc SVN::Hooks
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=SVN-Hooks>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/SVN-Hooks>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/SVN-Hooks>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/SVN-Hooks>
-
-=back
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2009 CPqD, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1; # End of SVN::Hooks::AllowPropChange
