@@ -1,7 +1,12 @@
-package SVN::Hooks::CheckMimeTypes;
-
 use strict;
 use warnings;
+
+package SVN::Hooks::CheckMimeTypes;
+{
+  $SVN::Hooks::CheckMimeTypes::VERSION = '1.13';
+}
+# ABSTRACT: Require the svn:mime-type property.
+
 use Carp;
 use SVN::Hooks;
 
@@ -9,39 +14,6 @@ use Exporter qw/import/;
 my $HOOK = 'CHECK_MIMETYPES';
 our @EXPORT = ($HOOK);
 
-our $VERSION = $SVN::Hooks::VERSION;
-
-=head1 NAME
-
-SVN::Hooks::CheckMimeTypes - Require the svn:mime-type property.
-
-=head1 SYNOPSIS
-
-This SVN::Hooks plugin checks if the files added to the repository
-have the B<svn:mime-type> property set. Moreover, for text files, it
-checks if the properties B<svn:eol-style> and B<svn:keywords> are also
-set.
-
-The plugin was based on the
-L<check-mime-type.pl|http://svn.digium.com/view/repotools/check-mime-type.pl>
-script.
-
-It's active in the C<pre-commit> hook.
-
-It's configured by the following directive.
-
-=head2 CHECK_MIMETYPES([MESSAGE])
-
-This directive enables the checking, causing the commit to abort if it
-doesn't comply.
-
-The MESSAGE argument is an optional help message shown to the user in
-case the commit fails. Note that by default the plugin already inserts
-a rather verbose help message in case of errors.
-
-	CHECK_MIMETYPES("Use TortoiseSVN -> Properties menu option to set properties.");
-
-=cut
 
 my $Help = <<"EOS";
 You may want to consider uncommenting the auto-props section
@@ -97,59 +69,57 @@ EOS
     }
 }
 
+1; # End of SVN::Hooks::CheckMimeTypes
+
+__END__
+=pod
+
+=head1 NAME
+
+SVN::Hooks::CheckMimeTypes - Require the svn:mime-type property.
+
+=head1 VERSION
+
+version 1.13
+
+=head1 SYNOPSIS
+
+This SVN::Hooks plugin checks if the files added to the repository
+have the B<svn:mime-type> property set. Moreover, for text files, it
+checks if the properties B<svn:eol-style> and B<svn:keywords> are also
+set.
+
+The plugin was based on the
+L<check-mime-type.pl|http://svn.digium.com/view/repotools/check-mime-type.pl>
+script.
+
+It's active in the C<pre-commit> hook.
+
+It's configured by the following directive.
+
+=head2 CHECK_MIMETYPES([MESSAGE])
+
+This directive enables the checking, causing the commit to abort if it
+doesn't comply.
+
+The MESSAGE argument is an optional help message shown to the user in
+case the commit fails. Note that by default the plugin already inserts
+a rather verbose help message in case of errors.
+
+	CHECK_MIMETYPES("Use TortoiseSVN -> Properties menu option to set properties.");
+
+=for Pod::Coverage pre_commit
+
 =head1 AUTHOR
 
-Gustavo Chaves, C<< <gnustavo@cpan.org> >>
+Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-Please report any bugs or feature requests to
-C<bug-svn-hooks-checkmimetypes at rt.cpan.org>, or through the web
-interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=SVN-Hooks>.  I will
-be notified, and then you'll automatically be notified of progress on
-your bug as I make changes.
+This software is copyright (c) 2012 by CPqD.
 
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc SVN::Hooks
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=SVN-Hooks>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/SVN-Hooks>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/SVN-Hooks>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/SVN-Hooks>
-
-=back
-
-=head1 ACKNOWLEDGEMENTS
-
-To the author of the C<check-mime-type.pl> script at
-L<http://svn.digium.com/view/repotools/check-mime-type.pl>.
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2008-2011 CPqD, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1; # End of SVN::Hooks::CheckMimeTypes
