@@ -1,7 +1,12 @@
-package SVN::Hooks::CheckProperty;
-
 use strict;
 use warnings;
+
+package SVN::Hooks::CheckProperty;
+{
+  $SVN::Hooks::CheckProperty::VERSION = '1.13';
+}
+# ABSTRACT: Check properties in added files.
+
 use Carp;
 use SVN::Hooks;
 
@@ -9,12 +14,86 @@ use Exporter qw/import/;
 my $HOOK = 'CHECK_PROPERTY';
 our @EXPORT = ($HOOK);
 
-our $VERSION = $SVN::Hooks::VERSION;
+
+my @Checks;
+
+sub CHECK_PROPERTY {
+    my ($where, $prop, $what) = @_;
+
+    defined $where and (not ref $where or ref $where eq 'Regexp')
+	or croak "$HOOK: first argument must be a STRING or a qr/Regexp/\n";
+    defined $prop and not ref $prop
+	or croak "$HOOK: second argument must be a STRING\n";
+    not defined $what or not ref $what or ref $what eq 'Regexp'
+	or croak "$HOOK: third argument must be undefined, or a NUMBER, or a STRING, or a qr/Regexp/\n";
+
+    push @Checks, [$where, $prop => $what];
+
+    PRE_COMMIT(\&pre_commit);
+
+    return 1;
+}
+
+sub pre_commit {
+    my ($svnlook) = @_;
+
+    my @errors;
+
+    foreach my $added ($svnlook->added()) {
+	foreach my $check (@Checks) {
+	    my ($where, $prop, $what) = @$check;
+	    if (ref $where eq 'Regexp' and $added =~ $where or
+		    $where eq substr($added, 0, length $where)) {
+		my $props = $svnlook->proplist($added);
+		my $is_set = exists $props->{$prop};
+		if (! defined $what) {
+		    $is_set or push @errors, "property $prop must be set for: $added";
+		}
+		elsif (! ref $what) {
+		    if ($what =~ /^\d+$/) {
+			if ($what) {
+			    $is_set or push @errors, "property $prop must be set for: $added";
+			}
+			else {
+			    $is_set and push @errors, "property $prop must not be set for: $added";
+			}
+		    }
+		    elsif (! $is_set) {
+			push @errors, "property $prop must be set to \"$what\" for: $added";
+		    }
+		    elsif ($props->{$prop} ne $what) {
+			push @errors, "property $prop must be set to \"$what\" and not to \"$props->{$prop}\" for: $added";
+		    }
+		}
+		elsif (! $is_set) {
+		    push @errors, "property $prop must be set and match \"$what\" for: $added";
+		}
+		elsif ($props->{$prop} !~ $what) {
+		    push @errors, "property $prop must match \"$what\" but is \"$props->{$prop}\" for: $added";
+		}
+	    }
+	}
+    }
+
+    croak join("\n", "$HOOK:", @errors), "\n"
+	if @errors;
+
+    return;
+}
+
+1; # End of SVN::Hooks::CheckProperty
+
+__END__
+=pod
 
 =head1 NAME
 
 SVN::Hooks::CheckProperty - Check properties in added files.
 
+=head1 VERSION
+
+version 1.13
+
 =head1 SYNOPSIS
 
 This SVN::Hooks plugin checks if some files added to the repository
@@ -63,124 +142,18 @@ Example:
 	CHECK_PROPERTY(qr/\.(?:do[ct]|od[bcfgimpst]|ot[ghpst]|pp[st]|xl[bst])$/i
 	       => 'svn:needs-lock');
 
-=cut
-
-sub CHECK_PROPERTY {
-    my ($where, $prop, $what) = @_;
-
-    defined $where and (not ref $where or ref $where eq 'Regexp')
-	or croak "$HOOK: first argument must be a STRING or a qr/Regexp/\n";
-    defined $prop and not ref $prop
-	or croak "$HOOK: second argument must be a STRING\n";
-    not defined $what or not ref $what or ref $what eq 'Regexp'
-	or croak "$HOOK: third argument must be undefined, or a NUMBER, or a STRING, or a qr/Regexp/\n";
-
-    my $conf = $SVN::Hooks::Confs->{$HOOK};
-    push @{$conf->{checks}}, [$where, $prop => $what];
-    $conf->{'pre-commit'} = \&pre_commit;
-
-    return 1;
-}
-
-$SVN::Hooks::Inits{$HOOK} = sub {
-    return { checks => [] };
-};
-
-sub pre_commit {
-    my ($self, $svnlook) = @_;
-
-    my @errors;
-
-    foreach my $added ($svnlook->added()) {
-	foreach my $check (@{$self->{checks}}) {
-	    my ($where, $prop, $what) = @$check;
-	    if (ref $where eq 'Regexp' and $added =~ $where or
-		    $where eq substr($added, 0, length $where)) {
-		my $props = $svnlook->proplist($added);
-		my $is_set = exists $props->{$prop};
-		if (! defined $what) {
-		    $is_set or push @errors, "property $prop must be set for: $added";
-		}
-		elsif (! ref $what) {
-		    if ($what =~ /^\d+$/) {
-			if ($what) {
-			    $is_set or push @errors, "property $prop must be set for: $added";
-			}
-			else {
-			    $is_set and push @errors, "property $prop must not be set for: $added";
-			}
-		    }
-		    elsif (! $is_set) {
-			push @errors, "property $prop must be set to \"$what\" for: $added";
-		    }
-		    elsif ($props->{$prop} ne $what) {
-			push @errors, "property $prop must be set to \"$what\" and not to \"$props->{$prop}\" for: $added";
-		    }
-		}
-		elsif (! $is_set) {
-		    push @errors, "property $prop must be set and match \"$what\" for: $added";
-		}
-		elsif ($props->{$prop} !~ $what) {
-		    push @errors, "property $prop must match \"$what\" but is \"$props->{$prop}\" for: $added";
-		}
-	    }
-	}
-    }
-
-    croak join("\n", "$HOOK:", @errors), "\n"
-	if @errors;
-
-    return;
-}
+=for Pod::Coverage pre_commit
 
 =head1 AUTHOR
 
-Gustavo Chaves, C<< <gnustavo@cpan.org> >>
+Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-Please report any bugs or feature requests to
-C<bug-svn-hooks-checkproperty at rt.cpan.org>, or through the web
-interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=SVN-Hooks>.  I will
-be notified, and then you'll automatically be notified of progress on
-your bug as I make changes.
+This software is copyright (c) 2012 by CPqD.
 
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc SVN::Hooks
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=SVN-Hooks>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/SVN-Hooks>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/SVN-Hooks>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/SVN-Hooks>
-
-=back
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2008-2009 CPqD, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1; # End of SVN::Hooks::CheckProperty
